# Citation Information

The unilateral semantics was originally conceived of by:

- Fine. ["A Theory of Truthmaker Content I: Conjunction, Disjunction and Negation."](https://doi.org/10.1007/s10992-016-9413-y) Journal of Philosophical Logic 46, no. 6 (December 2017): 658.

The version implemented follows Champollion and Bernard's revision of Fine's semantics:

- Champollion and Bernard. ["Negation and Modality in Unilateral Truthmaker Semantics."](https://doi.org/10.1007/s10988-023-09407-z) Linguistics and Philosophy, (August 2024).

## Theory Implementation

This theory implementation is part of the ModelChecker framework.
If you use this theory implementation in academic work, please cite:

Miguel Buitrago and Benjamin Brast-McKie, (2025).

